@@ -5,8 +5,9 @@ from flask_restful import reqparse
 
 
 class TestParameterController(ControllerBase):
-    def __init__(self):
+    def __init__(self, lock_obj):
         ControllerBase.__init__(self)
+        self._lock_obj = lock_obj
         self.parameter_service = ParameterService()
 
     def post(self):
@@ -15,6 +16,7 @@ class TestParameterController(ControllerBase):
         parser.add_argument('service_name', type=str, required=True)
         parser.add_argument('context_label', type=str, required=True)
         args = parser.parse_args()
-        test_parameter = self.parameter_service.create(args['name'], args['service_name'], args['context_label'])
-        self.db_session.commit()
-        return {'id': test_parameter.id}, 201
+        with self._lock_obj:
+            test_parameter = self.parameter_service.create(args['name'], args['service_name'], args['context_label'])
+            self.db_session.commit()
+            return {'id': test_parameter.id}, 201
