@@ -1,9 +1,9 @@
 from wafec.fi.hypothesis.models._base import Base, engine
 
 
-def run():
+def main(args=None):
     Base.metadata.create_all(engine)
 
 
 if __name__ == '__main__':
-    run()
+    main()
