@@ -1,7 +1,8 @@
+from . import parameter_client_factory
+
 import wrapt
 import logging
-
-from . import parameter_client_factory
+import copy
 
 LOG = logging.getLogger(__name__)
 
@@ -13,7 +14,7 @@ def make_wrapper(instance, service, context):
             d = instance
         elif hasattr(instance, '__dict__'):
             d = getattr(instance, '__dict__')
-        if d is not None:
+        if d is not None and 'keys' in d:
             instance = Wrapper(instance, service, context)
             for k in d.keys():
                 wrappee = make_wrapper(d[k], service, '{}.{}'.format(context, k))
@@ -47,3 +48,23 @@ class Wrapper(wrapt.ObjectProxy):
         except Exception:
             LOG.exception('Failed to send parameter info')
         return super(Wrapper, self).__getitem__(item)
+
+    def __copy__(self):
+        if self.__wrapped__ is None:
+            return None
+        return copy.copy(self.__wrapped__)
+
+    def __deepcopy__(self, memodict={}):
+        if self.__wrapped__ is None:
+            return None
+        return copy.deepcopy(self.__wrapped__, memodict)
+
+    def __reduce__(self):
+        if self.__wrapped__ is None:
+            return None
+        return self.__wrapped__.__reduce__()
+
+    def __reduce_ex__(self, protocol):
+        if self.__wrapped__ is None:
+            return None
+        return self.__wrapped__.__reduce_ex__(protocol)
